@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -109,7 +110,6 @@ AccessibleSlideSorterView::AccessibleSlideSorterView(
     const Reference<XAccessible>& rxParent,
     ::Window* pContentWindow)
     : AccessibleSlideSorterViewBase(MutexOwner::maMutex),
-      mpImpl(new Implementation(*this,rSlideSorter,pContentWindow)),
       mrSlideSorter(rSlideSorter),
       mxParent(rxParent),
       mnClientId(0),
@@ -121,6 +121,16 @@ AccessibleSlideSorterView::AccessibleSlideSorterView(
 
 
 
+
+void AccessibleSlideSorterView::Init()
+{
+    mpImpl.reset(new Implementation(*this,mrSlideSorter,mpContentWindow));
+}
+
+
+
+
+
 AccessibleSlideSorterView::~AccessibleSlideSorterView (void)
 {
     Destroyed ();
@@ -224,7 +234,7 @@ Reference<XAccessible > SAL_CALL AccessibleSlideSorterView::getAccessibleParent
     throw (uno::RuntimeException)
 {
     ThrowIfDisposed();
-    const vos::OGuard aSolarGuard (Application::GetSolarMutex());
+    const SolarMutexGuard aSolarGuard;
     Reference<XAccessible> xParent;
 
     if (mpContentWindow != NULL)
@@ -242,7 +252,7 @@ sal_Int32 SAL_CALL AccessibleSlideSorterView::getAccessibleIndexInParent (void)
 {
     OSL_ASSERT(getAccessibleParent().is());
     ThrowIfDisposed();
-    const vos::OGuard aSolarGuard (Application::GetSolarMutex());
+    const SolarMutexGuard aSolarGuard;
     sal_Int32 nIndexInParent(-1);
 
     
@@ -280,7 +290,7 @@ sal_Int16 SAL_CALL AccessibleSlideSorterView::getAccessibleRole (void)
     throw (uno::RuntimeException)
 {
     ThrowIfDisposed();
-    ::vos::OGuard aGuard (Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
     return String(SdResId(SID_SD_A11Y_I_SLIDEVIEW_D));
 }
@@ -292,7 +302,7 @@ sal_Int16 SAL_CALL AccessibleSlideSorterView::getAccessibleRole (void)
     throw (uno::RuntimeException)
 {
     ThrowIfDisposed();
-    ::vos::OGuard aGuard (Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
     return String(SdResId(SID_SD_A11Y_I_SLIDEVIEW_N));
 }
@@ -315,7 +325,7 @@ Reference<XAccessibleStateSet > SAL_CALL
     throw (uno::RuntimeException)
 {
     ThrowIfDisposed();
-    const vos::OGuard aSolarGuard (Application::GetSolarMutex());
+    const SolarMutexGuard aSolarGuard;
     ::utl::AccessibleStateSetHelper* pStateSet = new ::utl::AccessibleStateSetHelper();
 
     pStateSet->AddState(AccessibleStateType::FOCUSABLE);
@@ -434,7 +444,7 @@ Reference<XAccessible> SAL_CALL
 {
     ThrowIfDisposed();
     Reference<XAccessible> xAccessible;
-    const vos::OGuard aSolarGuard (Application::GetSolarMutex());
+    const SolarMutexGuard aSolarGuard;
 
     const Point aTestPoint (aPoint.X, aPoint.Y);  
     ::sd::slidesorter::model::SharedPageDescriptor pHitDescriptor (
@@ -453,7 +463,7 @@ awt::Rectangle SAL_CALL AccessibleSlideSorterView::getBounds (void)
     throw (uno::RuntimeException)
 {
     ThrowIfDisposed();
-    const vos::OGuard aSolarGuard (Application::GetSolarMutex());
+    const SolarMutexGuard aSolarGuard;
     awt::Rectangle aBBox;
 
     if (mpContentWindow != NULL)
@@ -499,7 +509,7 @@ awt::Point SAL_CALL AccessibleSlideSorterView::getLocationOnScreen()
     throw (uno::RuntimeException)
 {
     ThrowIfDisposed();
-    const vos::OGuard aSolarGuard( Application::GetSolarMutex() );
+    const SolarMutexGuard aSolarGuard;
     awt::Point aParentLocationOnScreen;
 
     Reference<XAccessible> xParent (getAccessibleParent());
@@ -544,7 +554,7 @@ void SAL_CALL AccessibleSlideSorterView::grabFocus (void)
     throw (uno::RuntimeException)
 {
     ThrowIfDisposed();
-    const vos::OGuard aSolarGuard (Application::GetSolarMutex());
+    const SolarMutexGuard aSolarGuard;
 
     if (mpContentWindow)
         mpContentWindow->GrabFocus();
@@ -583,7 +593,7 @@ void SAL_CALL AccessibleSlideSorterView::selectAccessibleChild (sal_Int32 nChild
         RuntimeException)
 {
     ThrowIfDisposed();
-    const vos::OGuard aSolarGuard (Application::GetSolarMutex());
+    const SolarMutexGuard aSolarGuard;
 
     AccessibleSlideSorterObject* pChild = mpImpl->GetAccessibleChild(nChildIndex);
     if (pChild != NULL)
@@ -601,7 +611,7 @@ sal_Bool SAL_CALL AccessibleSlideSorterView::isAccessibleChildSelected (sal_Int3
 {
     ThrowIfDisposed();
     sal_Bool bIsSelected = sal_False;
-    const vos::OGuard aSolarGuard (Application::GetSolarMutex());
+    const SolarMutexGuard aSolarGuard;
 
     AccessibleSlideSorterObject* pChild = mpImpl->GetAccessibleChild(nChildIndex);
     if (pChild != NULL)
@@ -620,7 +630,7 @@ void SAL_CALL AccessibleSlideSorterView::clearAccessibleSelection (void)
     throw (uno::RuntimeException)
 {
     ThrowIfDisposed();
-    const vos::OGuard aSolarGuard (Application::GetSolarMutex());
+    const SolarMutexGuard aSolarGuard;
 
     mrSlideSorter.GetController().GetPageSelector().DeselectAllPages();
 }
@@ -632,7 +642,7 @@ void SAL_CALL AccessibleSlideSorterView::selectAllAccessibleChildren (void)
     throw (uno::RuntimeException)
 {
     ThrowIfDisposed();
-    const vos::OGuard aSolarGuard (Application::GetSolarMutex());
+    const SolarMutexGuard aSolarGuard;
 
     mrSlideSorter.GetController().GetPageSelector().SelectAllPages();
 }
@@ -644,7 +654,7 @@ sal_Int32 SAL_CALL AccessibleSlideSorterView::getSelectedAccessibleChildCount (v
     throw (uno::RuntimeException)
 {
     ThrowIfDisposed ();
-    const vos::OGuard aSolarGuard (Application::GetSolarMutex());
+    const SolarMutexGuard aSolarGuard;
     return mrSlideSorter.GetController().GetPageSelector().GetSelectedPageCount();
 }
 
@@ -656,7 +666,7 @@ Reference<XAccessible > SAL_CALL
     throw (lang::IndexOutOfBoundsException, uno::RuntimeException)
 {
     ThrowIfDisposed ();
-    const vos::OGuard aSolarGuard (Application::GetSolarMutex());
+    const SolarMutexGuard aSolarGuard;
     Reference<XAccessible> xChild;
 
     ::sd::slidesorter::controller::PageSelector& rSelector (
@@ -689,7 +699,7 @@ void SAL_CALL AccessibleSlideSorterView::deselectAccessibleChild (sal_Int32 nChi
         RuntimeException)
 {
     ThrowIfDisposed();
-    const vos::OGuard aSolarGuard (Application::GetSolarMutex());
+    const SolarMutexGuard aSolarGuard;
 
     AccessibleSlideSorterObject* pChild = mpImpl->GetAccessibleChild(nChildIndex);
     if (pChild != NULL)
@@ -1079,3 +1089,5 @@ IMPL_LINK(AccessibleSlideSorterView::Implementation, VisibilityChangeListener, v
 
 
 } // end of namespace ::accessibility
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
