@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -39,9 +40,7 @@
 #include "cppuhelper/exc_hlp.hxx"
 #include "rtl/ref.hxx"
 
-#ifndef _SVXIDS_HRC
 #include <svx/svxids.hrc>
-#endif
 #include <svx/svdpagv.hxx>
 #include <sfx2/viewfrm.hxx>
 #include <sfx2/bindings.hxx>
@@ -61,10 +60,8 @@
 #include "misc.hxx"
 
 #ifdef STARIMAGE_AVAILABLE
-#ifndef _SIMDLL_HXX
 #include <sim2/simdll.hxx>
 #endif
-#endif
 
 #include <svx/dialogs.hrc>
 
@@ -84,9 +81,7 @@
 #include "FrameView.hxx"
 #include "stlpool.hxx"
 #include "Window.hxx"
-#ifndef SD_DRAWVIEW_HXX
 #include "drawview.hxx"
-#endif
 #include "drawdoc.hxx"
 #include "DrawDocShell.hxx"
 #include "Ruler.hxx"
@@ -1447,3 +1442,4 @@ sal_Int8 DrawViewShell::ExecuteDrop (
 #endif
 #endif
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
